@@ -1,12 +1,12 @@
 from extras.plugins import PluginConfig
 
-__version__ = "0.0.7.6.5.48"
+__version__ = "0.0.7.6.5.57"
 
 
 class DiskConfig(PluginConfig):
     name = "netbox_disk"
-    verbose_name = "Netbox Disk"
-    description = "Netbox Disk"
+    verbose_name = "Netbox Storage"
+    description = "Netbox Storage"
     min_version = "3.4.0"
     version = __version__
     author = "Tim Rhomberg"
