@@ -1,6 +1,6 @@
 from rest_framework import serializers
 
-from netbox_disk.models import Disk, Filesystem
+from netbox_disk.models import Drive, Filesystem
 from virtualization.api.nested_serializers import NestedClusterSerializer, NestedVirtualMachineSerializer
 
 
@@ -18,12 +18,12 @@ class FilesystemSerializer(serializers.ModelSerializer):
         )
 
 
-class DiskSerializer(serializers.ModelSerializer):
+class DriveSerializer(serializers.ModelSerializer):
     cluster = NestedClusterSerializer(required=False, allow_null=True)
     virtual_machine = NestedVirtualMachineSerializer(required=False, allow_null=True)
 
     class Meta:
-        model = Disk
+        model = Drive
         fields = (
             "id",
             "size",
