@@ -2,14 +2,14 @@ from netbox.api.routers import NetBoxRouter
 
 from netbox_disk.api.views import (
     NetboxDiskRootView,
-    DiskViewSet,
+    DriveViewSet,
     FilesystemViewSet,
 )
 
 router = NetBoxRouter()
 router.APIRootView = NetboxDiskRootView
 
-router.register("disk", DiskViewSet)
+router.register("drive", DriveViewSet)
 router.register("filesystem", FilesystemViewSet)
 
 urlpatterns = router.urls
