@@ -1,30 +1,28 @@
-from django.db.models.functions import Length
-
 from extras.plugins import PluginTemplateExtension
 
-from netbox_disk.models import Disk
-from netbox_disk.tables import RelatedDiskTable
+from netbox_disk.models import Drive
+from netbox_disk.tables import RelatedDriveTable
 
 
-class RelatedDisks(PluginTemplateExtension):
+class RelatedDrives(PluginTemplateExtension):
     model = "virtualization.virtualmachine"
 
     def right_page(self):
         obj = self.context.get("object")
 
-        disks = Disk.objects.filter(
+        drives = Drive.objects.filter(
             virtual_machine=obj
         )
-        disk_table = RelatedDiskTable(
-            data=disks
+        drive_table = RelatedDriveTable(
+            data=drives
         )
 
         return self.render(
             "netbox_disk/disk/disk_box.html",
             extra_context={
-                "related_disks": disk_table,
+                "related_drives": drive_table,
             },
         )
 
 
-template_extensions = [RelatedDisks]
+template_extensions = [RelatedDrives]
